Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(979)

Unified Diff: chrome/browser/resources/tracing/timeline_view.js

Issue 7555005: Moving the contents of chrome://gpu Profiling to chrome://tracing. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/tracing/timeline_view.js
diff --git a/chrome/browser/resources/gpu_internals/timeline_view.js b/chrome/browser/resources/tracing/timeline_view.js
similarity index 95%
rename from chrome/browser/resources/gpu_internals/timeline_view.js
rename to chrome/browser/resources/tracing/timeline_view.js
index c4e1c3e63f456ac68ff153fbc20890cfd0020e73..107ba4863094b83c2a498321af9ad80ee40c0ec7 100644
--- a/chrome/browser/resources/gpu_internals/timeline_view.js
+++ b/chrome/browser/resources/tracing/timeline_view.js
@@ -4,10 +4,10 @@
/**
* @fileoverview TimelineView visualizes GPU_TRACE events using the
* gpu.Timeline component.
*/
-cr.define('gpu', function() {
+cr.define('tracing', function() {
function tsRound(ts) {
return Math.round(ts * 1000.0) / 1000.0;
}
@@ -65,14 +65,14 @@ cr.define('gpu', function() {
set traceEvents(traceEvents) {
console.log('TimelineView.refresh');
- this.timelineModel_ = new gpu.TimelineModel(traceEvents);
+ this.timelineModel_ = new tracing.TimelineModel(traceEvents);
// remove old timeline
this.timelineContainer_.textContent = '';
// create new timeline if needed
if (traceEvents.length) {
- this.timeline_ = new gpu.Timeline();
+ this.timeline_ = new tracing.Timeline();
this.timeline_.model = this.timelineModel_;
this.timelineContainer_.appendChild(this.timeline_);
this.timeline_.onResize();
@@ -4,10 +4,10 @@
/**
- * @fileoverview TimelineView visualizes GPU_TRACE events using the
- * gpu.Timeline component.
+ * @fileoverview TimelineView visualizes TRACE_EVENT events using the
+ * tracing.Timeline component.
*/
« no previous file with comments | « chrome/browser/resources/tracing/timeline_view.css ('k') | chrome/browser/resources/tracing/tracing_controller.css » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698